@@ -1,4 +1,4 @@
-# version  : 2.05 - November 2020
+# version  : 2.06 - November 2020
 # author   : Thierry LE GALL 
 # contact  : facila@gmx.fr
 
@@ -21,7 +21,7 @@ use 5.006;
 use strict;
 use warnings;
 
-our $VERSION = '2.05';
+our $VERSION = '2.06';
 
 my @mask = qw ( 0.0.0.0
 128.0.0.0       192.0.0.0       224.0.0.0       240.0.0.0       248.0.0.0       252.0.0.0       254.0.0.0       255.0.0.0
@@ -556,15 +556,15 @@ __END__
   u = for uniques lines only      , default = for all lines 
 
  examples :
- $list  = "ip route 5.0.0.0 255.0.0.0 192.168.5.254\n"
- $list .= "ip route 3.0.0.0 255.0.0.0 192.168.99.254\n"
- $list .= "ip route 11.0.0.0 255.0.0.0 192.168.45.254\n"
- $list .= "ip route 2.0.0.0 255.0.0.0 172.32.21.254\n"
- $list .= "ip route 1.0.0.0 255.0.0.0 10.69.14.254\n"
- $list .= "ip route 23.0.0.0 255.0.0.0 192.168.0.254\n"
- $list .= "ip route 2.0.0.0 255.0.0.0 172.32.21.254\n"
- $list .= "ip route 8.0.0.0 255.0.0.0 10.31.21.254\n"
- $list .= "ip route 210.0.0.0 255.0.0.0 172.16.78.254\n"
+ $list  = "ip route 5.0.0.0 255.0.0.0 192.168.5.254\n";
+ $list .= "ip route 3.0.0.0 255.0.0.0 192.168.99.254\n";
+ $list .= "ip route 11.0.0.0 255.0.0.0 192.168.45.254\n";
+ $list .= "ip route 2.0.0.0 255.0.0.0 172.32.21.254\n";
+ $list .= "ip route 1.0.0.0 255.0.0.0 10.69.14.254\n";
+ $list .= "ip route 23.0.0.0 255.0.0.0 192.168.0.254\n";
+ $list .= "ip route 2.0.0.0 255.0.0.0 172.32.21.254\n";
+ $list .= "ip route 8.0.0.0 255.0.0.0 10.31.21.254\n";
+ $list .= "ip route 210.0.0.0 255.0.0.0 172.16.78.254\n";
  
   - sort ($list)
   - sort ($list,'3')
@@ -628,7 +628,7 @@ __END__
 
 =head1 VERSION AND AUTHOR
 
- Version  : v2.05 - November 2020
+ Version  : v2.06 - November 2020
  Author   : Thierry LE GALL
  Contact  : facila@gmx.fr
 
